ContainerCreateResult class final

Result from POST /containers/create.

Constructors

ContainerCreateResult({required String id, required List<String> warnings, required Map<String, Object?> raw})
Creates a container create result.
const
ContainerCreateResult.fromJson(Map<String, Object?> json)
Builds ContainerCreateResult from API JSON payload.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
Created container ID.
final
raw Map<String, Object?>
Raw parsed JSON payload.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
warnings List<String>
Podman warning messages.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited