ContainerHealthStatus class final

Container health status from inspect payload.

Constructors

ContainerHealthStatus({required String status, required int failingStreak, required Map<String, Object?> raw})
Creates health status.
const
ContainerHealthStatus.fromInspect(Map<String, Object?> inspectJson)
Builds ContainerHealthStatus from inspect JSON.
factory

Properties

failingStreak int
Consecutive failing checks.
final
hashCode int
The hash code for this object.
no setterinherited
raw Map<String, Object?>
Raw health-check object from inspect payload.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String
Health status (healthy, unhealthy, starting, or none).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited