ManifestCreateResult class final

Manifest create result from POST /libpod/manifests/{name}.

Constructors

ManifestCreateResult({required String id, required Map<String, Object?> raw})
Creates manifest create result.
const
ManifestCreateResult.fromJson(Map<String, Object?> json)
Builds ManifestCreateResult from JSON.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
Manifest/image ID.
final
raw Map<String, Object?>
Raw payload.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited