NetworkPruneOptions class final

Options for POST /libpod/networks/prune.

Constructors

NetworkPruneOptions({Map<String, List<String>> filters = const <String, List<String>>{}})
Creates network prune options.
const

Properties

filters Map<String, List<String>>
Prune filters.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toQueryParameters() Map<String, List<String>>
Serializes options to query parameters.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited