PlayKubeOptions class final

Options for play kube operations.

Constructors

PlayKubeOptions({List<String> networks = const <String>[], bool noHosts = false, bool noTrunc = false, List<String> publishPorts = const <String>[], bool publishAllPorts = false, bool replace = false, bool serviceContainer = false, bool? start, List<String> staticIps = const <String>[], List<String> staticMacs = const <String>[], bool? tlsVerify, String? userns, bool wait = false, bool? build})
Creates play-kube options.
const

Properties

build bool?
Build missing images.
final
hashCode int
The hash code for this object.
no setterinherited
networks List<String>
Networks for created pods.
final
noHosts bool
Do not create /etc/hosts.
final
noTrunc bool
Use non-truncated annotations.
final
publishAllPorts bool
Publish all declared ports.
final
publishPorts List<String>
Port publish specs.
final
replace bool
Replace existing resources.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serviceContainer bool
Start a service container first.
final
start bool?
Start resources after creation.
final
staticIps List<String>
Static IPs for pods.
final
staticMacs List<String>
Static MACs for pods.
final
tlsVerify bool?
TLS verification preference.
final
userns String?
User namespace mode.
final
wait bool
Wait and clean up when pods exit.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toQueryParameters() Map<String, List<String>>
Serializes to query parameters.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited