PodDetails class final

Detailed pod data from GET /libpod/pods/{name}/json.

Constructors

PodDetails({required String id, required String name, required String state, required String cgroup, required Map<String, String> labels, required DateTime? createdAt, required List<String> containerIds, required Map<String, Object?> raw})
Creates pod details.
const
PodDetails.fromJson(Map<String, Object?> json)
Builds PodDetails from JSON.
factory

Properties

cgroup String
Pod cgroup parent.
final
containerIds List<String>
IDs of containers belonging to the pod.
final
createdAt DateTime?
Creation timestamp.
final
hashCode int
The hash code for this object.
no setterinherited
id String
Pod ID.
final
labels Map<String, String>
Pod labels.
final
name String
Pod name.
final
raw Map<String, Object?>
Raw payload.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state String
Pod state.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited