PodmanClient class final

High-level Podman libpod API client.

Available extensions

Constructors

PodmanClient({PodmanTransport? transport, String apiVersion = 'v5.0.0', String? socketPath})
Creates a Podman API client.

Properties

apiVersion String
API version prefix.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addArtifact(String name, {required String fileName, required List<int> fileBytes, ArtifactAddOptions options = const ArtifactAddOptions(), Duration? timeout}) Future<ArtifactAddResult>

Available on PodmanClient, provided by the PodmanClientArtifactsApi extension

Adds a binary blob as a new or existing OCI artifact entry.
addLocalArtifact(String name, {required String path, required String fileName, ArtifactAddOptions options = const ArtifactAddOptions(), Duration? timeout}) Future<ArtifactAddResult>

Available on PodmanClient, provided by the PodmanClientArtifactsApi extension

Adds a server-local file as an OCI artifact entry.
checkpointContainer(String container, {ContainerCheckpointOptions options = const ContainerCheckpointOptions(), Duration? timeout}) Future<ContainerCheckpointReport>

Available on PodmanClient, provided by the PodmanClientContainerCheckpointApi extension

Checkpoints a container and returns the report.
close() Future<void>
Closes underlying transport resources.
connectNetwork(String network, NetworkConnectOptions options, {Duration? timeout}) Future<void>

Available on PodmanClient, provided by the PodmanClientNetworkApi extension

Connects a container to a network.
containerExists(String container, {Duration? timeout}) Future<bool>

Available on PodmanClient, provided by the PodmanClientContainerApi extension

Whether a container exists.
createContainer(RunOptions options, {Duration? timeout}) Future<ContainerCreateResult>

Available on PodmanClient, provided by the PodmanClientContainerApi extension

Creates a container without starting it.
createExec(String container, ExecCreateOptions options, {Duration? timeout}) Future<ContainerExecCreateResult>

Available on PodmanClient, provided by the PodmanClientContainerRuntimeApi extension

Creates an exec process in a running container.
createManifest(String name, {ManifestCreateOptions options = const ManifestCreateOptions(), Duration? timeout}) Future<ManifestCreateResult>

Available on PodmanClient, provided by the PodmanClientManifestApi extension

Creates a manifest list.
createNetwork(NetworkCreateOptions options, {Duration? timeout}) Future<NetworkDetails>

Available on PodmanClient, provided by the PodmanClientNetworkApi extension

Creates a network.
createPod(PodCreateOptions options, {Duration? timeout}) Future<PodDetails>

Available on PodmanClient, provided by the PodmanClientPodApi extension

Creates a pod.
createSecret(SecretCreateOptions options, {Duration? timeout}) Future<SecretCreateResult>

Available on PodmanClient, provided by the PodmanClientSecretsApi extension

Creates a secret.
createVolume(VolumeCreateOptions options, {Duration? timeout}) Future<VolumeDetails>

Available on PodmanClient, provided by the PodmanClientVolumeApi extension

Creates a volume.
deleteManifest(String name, {bool ignoreMissing = false, Duration? timeout}) Future<ManifestDeleteResult>

Available on PodmanClient, provided by the PodmanClientManifestApi extension

Deletes a manifest list.
disconnectNetwork(String network, {required String container, bool force = false, bool ignoreMissing = false, Duration? timeout}) Future<void>

Available on PodmanClient, provided by the PodmanClientNetworkApi extension

Disconnects a container from a network.
exportContainerCheckpoint(String container, {ContainerCheckpointOptions options = const ContainerCheckpointOptions(), Duration? timeout}) Future<List<int>>

Available on PodmanClient, provided by the PodmanClientContainerCheckpointApi extension

Exports a container checkpoint archive as tar bytes.
exportImage(String image, {ImageExportOptions options = const ImageExportOptions(), Duration? timeout}) Future<Uint8List>

Available on PodmanClient, provided by the PodmanClientImageApi extension

Exports a single image archive.
exportImages(Iterable<String> references, {ImageExportOptions options = const ImageExportOptions(), Duration? timeout}) Future<Uint8List>

Available on PodmanClient, provided by the PodmanClientImageApi extension

Exports one or more image references into a single archive.
exportVolume(String volume, {Duration? timeout}) Future<Uint8List>

Available on PodmanClient, provided by the PodmanClientVolumeApi extension

Exports volume contents as a tar archive.
extractArtifact(String name, {String? title, String? digest, bool excludeTitle = false, Duration? timeout}) Future<Uint8List>

Available on PodmanClient, provided by the PodmanClientArtifactsApi extension

Extracts artifact content as a tar stream.
generateKube(GenerateKubeOptions options, {Duration? timeout}) Future<String>

Available on PodmanClient, provided by the PodmanClientKubeApi extension

Generates Kubernetes YAML for containers/pods.
generateSystemd(String name, {GenerateSystemdOptions options = const GenerateSystemdOptions(), Duration? timeout}) Future<GenerateSystemdResult>

Available on PodmanClient, provided by the PodmanClientKubeApi extension

Generates systemd units for a pod/container.
getContainerArchive(String container, {required String path, Map<String, String> rename = const <String, String>{}, Duration? timeout}) Future<ContainerArchiveGetResult>

Available on PodmanClient, provided by the PodmanClientContainerArchiveApi extension

Copies a container path as a tar archive.
headContainerArchive(String container, {required String path, Duration? timeout}) Future<String?>

Available on PodmanClient, provided by the PodmanClientContainerArchiveApi extension

Reads archive metadata headers for a path in a container.
healthStatus(String container, {Duration? timeout}) Future<ContainerHealthStatus>

Available on PodmanClient, provided by the PodmanClientContainerRuntimeApi extension

Returns container health status (or none when no healthcheck exists).
imageExists(String image, {Duration? timeout}) Future<bool>

Available on PodmanClient, provided by the PodmanClientImageApi extension

Whether an image exists locally.
imageHistory(String image, {Duration? timeout}) Future<List<ImageHistoryEntry>>

Available on PodmanClient, provided by the PodmanClientImageApi extension

Returns image history entries.
imageTree(String image, {bool whatRequires = false, Duration? timeout}) Future<ImageTreeReport>

Available on PodmanClient, provided by the PodmanClientImageApi extension

Returns a printable image tree report.
importImage({ImageImportOptions options = const ImageImportOptions(), List<int>? archiveBytes, Duration? timeout}) Future<ImageImportReport>

Available on PodmanClient, provided by the PodmanClientImageApi extension

Imports an image from request body bytes or from a URL in options.
importVolume(String volume, {required List<int> archiveBytes, Duration? timeout}) Future<void>

Available on PodmanClient, provided by the PodmanClientVolumeApi extension

Imports volume contents from an uncompressed tar archive.
info({Duration? timeout}) Future<PodmanInfo>

Available on PodmanClient, provided by the PodmanClientSystemApi extension

Returns Podman host/runtime information.
initContainer(String container, {Duration? timeout}) Future<void>

Available on PodmanClient, provided by the PodmanClientContainerAdminApi extension

Performs container initialization tasks without starting it.
inspectArtifact(String name, {Duration? timeout}) Future<ArtifactDetails>

Available on PodmanClient, provided by the PodmanClientArtifactsApi extension

Inspects a local OCI artifact by name or digest.
inspectContainer(String container, {Duration? timeout}) Future<ContainerDetails>

Available on PodmanClient, provided by the PodmanClientContainerApi extension

Inspects a single container.
inspectExec(String execId, {Duration? timeout}) Future<ContainerExecInspectResult>

Available on PodmanClient, provided by the PodmanClientContainerRuntimeApi extension

Inspects an exec process.
inspectImage(String image, {Duration? timeout}) Future<ImageDetails>

Available on PodmanClient, provided by the PodmanClientImageApi extension

Inspects a local image by name or ID.
inspectManifest(String name, {bool? tlsVerify, Duration? timeout}) Future<ManifestDetails>

Available on PodmanClient, provided by the PodmanClientManifestApi extension

Inspects a manifest list.
inspectNetwork(String network, {Duration? timeout}) Future<NetworkDetails>

Available on PodmanClient, provided by the PodmanClientNetworkApi extension

Inspects a network by name or ID.
inspectPod(String pod, {Duration? timeout}) Future<PodDetails>

Available on PodmanClient, provided by the PodmanClientPodApi extension

Inspects a pod by name or ID.
inspectSecret(String secret, {bool showSecret = false, Duration? timeout}) Future<SecretDetails>

Available on PodmanClient, provided by the PodmanClientSecretsApi extension

Inspects a secret.
inspectVolume(String volume, {Duration? timeout}) Future<VolumeDetails>

Available on PodmanClient, provided by the PodmanClientVolumeApi extension

Inspects a volume.
killContainer(String container, {String signal = 'KILL', Duration? timeout}) Future<void>

Available on PodmanClient, provided by the PodmanClientContainerAdminApi extension

Sends a signal to a running container.
killPod(String pod, {String signal = 'SIGKILL', Duration? timeout}) Future<void>

Available on PodmanClient, provided by the PodmanClientPodApi extension

Kills running containers in a pod.
listArtifacts({Duration? timeout}) Future<List<ArtifactSummary>>

Available on PodmanClient, provided by the PodmanClientArtifactsApi extension

Lists local OCI artifacts.
listContainers({bool all = true, Duration? timeout}) Future<List<ContainerSummary>>

Available on PodmanClient, provided by the PodmanClientContainerApi extension

Lists containers.
listEvents({Iterable<PodmanEventFilter> filters = const <PodmanEventFilter>[], DateTime? since, DateTime? until, bool fromStart = false, Duration? timeout}) Future<List<PodmanEvent>>

Available on PodmanClient, provided by the PodmanClientEventsApi extension

Fetches events from /libpod/events in non-streaming mode.
listImages({bool all = false, Map<String, List<String>> filters = const <String, List<String>>{}, Duration? timeout}) Future<List<ImageSummary>>

Available on PodmanClient, provided by the PodmanClientImageApi extension

Lists available images.
listNetworks({Duration? timeout}) Future<List<NetworkSummary>>

Available on PodmanClient, provided by the PodmanClientNetworkApi extension

Lists available networks.
listPods({Duration? timeout}) Future<List<PodSummary>>

Available on PodmanClient, provided by the PodmanClientPodApi extension

Lists pods.
listSecrets({Duration? timeout}) Future<List<SecretSummary>>

Available on PodmanClient, provided by the PodmanClientSecretsApi extension

Lists secrets.
listVolumes({VolumeListOptions options = const VolumeListOptions(), Duration? timeout}) Future<List<VolumeSummary>>

Available on PodmanClient, provided by the PodmanClientVolumeApi extension

Lists known volumes.
loadImages(List<int> archiveBytes, {Duration? timeout}) Future<ImageLoadReport>

Available on PodmanClient, provided by the PodmanClientImageApi extension

Loads images from a tar archive payload.
loadImagesFromPath(String path, {Duration? timeout}) Future<ImageLoadReport>

Available on PodmanClient, provided by the PodmanClientImageApi extension

Loads images from a server-local archive path.
logs(String container, {int? tail, DateTime? since, DateTime? until, bool follow = false, bool timestamps = false, bool stdout = true, bool stderr = true, Duration? timeout}) Future<String>

Available on PodmanClient, provided by the PodmanClientContainerApi extension

Fetches container logs.
manifestExists(String name, {Duration? timeout}) Future<bool>

Available on PodmanClient, provided by the PodmanClientManifestApi extension

Whether a manifest list exists.
mountContainer(String container, {Duration? timeout}) Future<String>

Available on PodmanClient, provided by the PodmanClientContainerAdminApi extension

Mounts a container filesystem and returns its host mount path.
networkExists(String network, {Duration? timeout}) Future<bool>

Available on PodmanClient, provided by the PodmanClientNetworkApi extension

Whether a network exists.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pauseContainer(String container, {Duration? timeout}) Future<void>

Available on PodmanClient, provided by the PodmanClientContainerAdminApi extension

Pauses all processes in a container.
pausePod(String pod, {Duration? timeout}) Future<void>

Available on PodmanClient, provided by the PodmanClientPodApi extension

Pauses running containers in a pod.
playKube(String yaml, {PlayKubeOptions options = const PlayKubeOptions(), Duration? timeout}) Future<PlayKubeReport>

Available on PodmanClient, provided by the PodmanClientKubeApi extension

Plays a Kubernetes YAML document.
playKubeDown(String yaml, {bool force = false, Duration? timeout}) Future<PlayKubeReport>

Available on PodmanClient, provided by the PodmanClientKubeApi extension

Tears down resources defined in a Kubernetes YAML document.
podExists(String pod, {Duration? timeout}) Future<bool>

Available on PodmanClient, provided by the PodmanClientPodApi extension

Whether a pod exists.
podStats({PodStatsOptions options = const PodStatsOptions(), Duration? timeout}) Future<List<PodStatsReport>>

Available on PodmanClient, provided by the PodmanClientPodApi extension

Returns pod stats for one or more pods.
pruneContainers({Duration? timeout}) Future<void>

Available on PodmanClient, provided by the PodmanClientContainerApi extension

Removes stopped containers.
pruneImages({bool all = false, Duration? timeout}) Future<void>

Available on PodmanClient, provided by the PodmanClientImageApi extension

Removes unused images.
pruneNetworks({NetworkPruneOptions options = const NetworkPruneOptions(), Duration? timeout}) Future<List<NetworkPruneReport>>

Available on PodmanClient, provided by the PodmanClientNetworkApi extension

Prunes unused networks.
prunePods({Duration? timeout}) Future<List<PodPruneReport>>

Available on PodmanClient, provided by the PodmanClientPodApi extension

Prunes unused pods.
pruneVolumes({VolumePruneOptions options = const VolumePruneOptions(), Duration? timeout}) Future<List<VolumePruneReport>>

Available on PodmanClient, provided by the PodmanClientVolumeApi extension

Prunes unused volumes.
pull(String image, {bool quiet = false, Duration? timeout}) Future<String>

Available on PodmanClient, provided by the PodmanClientImageApi extension

Pulls an image and returns the raw API response body.
pullArtifact(String name, {ArtifactPullOptions options = const ArtifactPullOptions(), Duration? timeout}) Future<ArtifactPullResult>

Available on PodmanClient, provided by the PodmanClientArtifactsApi extension

Pulls an OCI artifact from a registry.
pushArtifact(String name, {ArtifactPushOptions options = const ArtifactPushOptions(), Duration? timeout}) Future<ArtifactPushResult>

Available on PodmanClient, provided by the PodmanClientArtifactsApi extension

Pushes an OCI artifact to a registry.
pushImage(String image, {ImagePushOptions options = const ImagePushOptions(), Duration? timeout}) Future<List<ImagePushEvent>>

Available on PodmanClient, provided by the PodmanClientImageApi extension

Pushes an image to a registry.
pushManifest(String name, String destination, {bool all = true, bool? tlsVerify, bool quiet = true, Duration? timeout}) Future<ManifestPushResult>

Available on PodmanClient, provided by the PodmanClientManifestApi extension

Pushes a manifest list to a registry.
putContainerArchive(String container, {required String path, required List<int> archiveBytes, bool copyUidGid = true, bool noOverwriteDirNonDir = false, Map<String, String> rename = const <String, String>{}, Duration? timeout}) Future<void>

Available on PodmanClient, provided by the PodmanClientContainerArchiveApi extension

Extracts a tar archive into a container path.
removeArtifact(String name, {bool ignoreMissing = false, Duration? timeout}) Future<ArtifactRemoveResult>

Available on PodmanClient, provided by the PodmanClientArtifactsApi extension

Removes a single OCI artifact.
removeArtifacts(ArtifactRemoveOptions options, {Duration? timeout}) Future<ArtifactRemoveResult>

Available on PodmanClient, provided by the PodmanClientArtifactsApi extension

Removes one or more artifacts, or all artifacts.
removeContainer(String container, {bool force = false, bool removeVolumes = false, bool ignoreMissing = false, Duration? timeout}) Future<void>

Available on PodmanClient, provided by the PodmanClientContainerApi extension

Removes a container.
removeImage(String image, {bool force = false, bool ignoreMissing = false, Duration? timeout}) Future<void>

Available on PodmanClient, provided by the PodmanClientImageApi extension

Removes an image.
removeImages(ImageRemoveOptions options, {Duration? timeout}) Future<ImageRemoveResult>

Available on PodmanClient, provided by the PodmanClientImageApi extension

Removes one or more images.
removeNetwork(String network, {bool force = false, bool ignoreMissing = false, Duration? timeout}) Future<void>

Available on PodmanClient, provided by the PodmanClientNetworkApi extension

Removes a network.
removePod(String pod, {bool force = false, bool ignoreMissing = false, Duration? timeout}) Future<void>

Available on PodmanClient, provided by the PodmanClientPodApi extension

Removes a pod.
removeSecret(String secret, {bool ignoreMissing = false, Duration? timeout}) Future<void>

Available on PodmanClient, provided by the PodmanClientSecretsApi extension

Removes a secret.
removeVolume(String volume, {bool force = false, bool ignoreMissing = false, Duration? timeout}) Future<void>

Available on PodmanClient, provided by the PodmanClientVolumeApi extension

Removes a volume.
renameContainer(String container, {required String name, Duration? timeout}) Future<void>

Available on PodmanClient, provided by the PodmanClientContainerAdminApi extension

Renames a container.
resizeContainerTty(String container, {required int width, required int height, bool ignoreNotRunning = false, Duration? timeout}) Future<void>

Available on PodmanClient, provided by the PodmanClientContainerRuntimeApi extension

Resizes a container TTY.
resizeExecTty(String execId, {required int width, required int height, bool ignoreNotRunning = false, Duration? timeout}) Future<void>

Available on PodmanClient, provided by the PodmanClientContainerRuntimeApi extension

Resizes an exec session TTY.
restart(String container, {int? timeoutSeconds, Duration? timeout}) Future<void>

Available on PodmanClient, provided by the PodmanClientContainerApi extension

Restarts a container.
restartPod(String pod, {Duration? timeout}) Future<void>

Available on PodmanClient, provided by the PodmanClientPodApi extension

Restarts containers in a pod.
restoreContainer(String container, {ContainerRestoreOptions options = const ContainerRestoreOptions(), Duration? timeout}) Future<ContainerRestoreReport>

Available on PodmanClient, provided by the PodmanClientContainerCheckpointApi extension

Restores a previously checkpointed container.
restoreContainerFromArchive(List<int> archiveBytes, {String importName = 'import', ContainerRestoreOptions options = const ContainerRestoreOptions(), Duration? timeout}) Future<ContainerRestoreReport>

Available on PodmanClient, provided by the PodmanClientContainerCheckpointApi extension

Restores a container from checkpoint archive bytes.
run(RunOptions options, {Duration? timeout}) Future<String>

Available on PodmanClient, provided by the PodmanClientContainerApi extension

Creates and starts a container, returning the container ID.
secretExists(String secret, {Duration? timeout}) Future<bool>

Available on PodmanClient, provided by the PodmanClientSecretsApi extension

Whether a secret exists.
showMountedContainers({Duration? timeout}) Future<Map<String, String>>

Available on PodmanClient, provided by the PodmanClientContainerAdminApi extension

Lists mounted containers and their mount paths keyed by container ID.
start(String container, {Duration? timeout}) Future<void>

Available on PodmanClient, provided by the PodmanClientContainerApi extension

Starts a container.
startExec(String execId, {bool detach = false, bool tty = false, Duration? timeout}) Future<ContainerExecStartResult>

Available on PodmanClient, provided by the PodmanClientContainerRuntimeApi extension

Starts an exec process and captures output.
startPod(String pod, {Duration? timeout}) Future<void>

Available on PodmanClient, provided by the PodmanClientPodApi extension

Starts a pod.
stats(String container, {bool stream = false, Duration? timeout}) Future<ContainerStats>

Available on PodmanClient, provided by the PodmanClientContainerRuntimeApi extension

Returns a single stats snapshot.
stop(String container, {int? timeoutSeconds, Duration? timeout}) Future<void>

Available on PodmanClient, provided by the PodmanClientContainerApi extension

Stops a container.
stopPod(String pod, {int? timeoutSeconds, Duration? timeout}) Future<void>

Available on PodmanClient, provided by the PodmanClientPodApi extension

Stops a pod.
systemCheck({SystemCheckOptions options = const SystemCheckOptions(), Duration? timeout}) Future<SystemCheckReport>

Available on PodmanClient, provided by the PodmanClientSystemApi extension

Performs storage consistency checks.
systemDf({Duration? timeout}) Future<SystemDfReport>

Available on PodmanClient, provided by the PodmanClientSystemApi extension

Returns libpod disk usage details.
systemPrune({SystemPruneOptions options = const SystemPruneOptions(), Duration? timeout}) Future<SystemPruneReport>

Available on PodmanClient, provided by the PodmanClientSystemApi extension

Prunes unused data from the local podman store.
tagImage(String source, String target, {Duration? timeout}) Future<void>

Available on PodmanClient, provided by the PodmanClientImageApi extension

Adds a tag to an image.
topContainer(String container, {ContainerTopOptions options = const ContainerTopOptions(), Duration? timeout}) Future<ContainerTopReport>

Available on PodmanClient, provided by the PodmanClientContainerAdminApi extension

Lists processes running in a container.
topPod(String pod, {PodTopOptions options = const PodTopOptions(), Duration? timeout}) Future<PodTopReport>

Available on PodmanClient, provided by the PodmanClientPodApi extension

Lists processes running in a pod.
toString() String
A string representation of this object.
inherited
unmountContainer(String container, {Duration? timeout}) Future<void>

Available on PodmanClient, provided by the PodmanClientContainerAdminApi extension

Unmounts a mounted container filesystem.
unpauseContainer(String container, {Duration? timeout}) Future<void>

Available on PodmanClient, provided by the PodmanClientContainerAdminApi extension

Unpauses a paused container.
unpausePod(String pod, {Duration? timeout}) Future<void>

Available on PodmanClient, provided by the PodmanClientPodApi extension

Unpauses containers in a pod.
updateContainer(String container, ContainerUpdateOptions options, {Duration? timeout}) Future<String?>

Available on PodmanClient, provided by the PodmanClientContainerAdminApi extension

Updates mutable container configuration values.
updateNetwork(String network, NetworkUpdateOptions options, {Duration? timeout}) Future<void>

Available on PodmanClient, provided by the PodmanClientNetworkApi extension

Updates mutable network settings.
version({Duration? timeout}) Future<PodmanVersion>

Available on PodmanClient, provided by the PodmanClientSystemApi extension

Returns Podman version metadata.
volumeExists(String volume, {Duration? timeout}) Future<bool>

Available on PodmanClient, provided by the PodmanClientVolumeApi extension

Whether a volume exists.
wait(String container, {Iterable<String> conditions = const <String>['stopped'], Duration? timeout}) Future<ContainerWaitResult>

Available on PodmanClient, provided by the PodmanClientContainerRuntimeApi extension

Waits for container state changes and returns wait status code.
watchContainerTop(String container, {ContainerTopOptions options = const ContainerTopOptions(), Duration pollInterval = const Duration(seconds: 2), bool reconnect = true, Duration reconnectDelay = const Duration(seconds: 1), Duration? timeout}) Stream<ContainerTopReport>

Available on PodmanClient, provided by the PodmanClientContainerRuntimeApi extension

Polls container top output continuously.
watchEvents({Iterable<PodmanEventFilter> filters = const <PodmanEventFilter>[], DateTime? since, bool fromStart = false, Duration pollInterval = const Duration(seconds: 1), bool reconnect = true, Duration reconnectDelay = const Duration(seconds: 1)}) Stream<PodmanEvent>

Available on PodmanClient, provided by the PodmanClientEventsApi extension

Watches events continuously with reconnect support.
watchLogs(String container, {int? tail, bool timestamps = true, bool stdout = true, bool stderr = true, DateTime? since, Duration pollInterval = const Duration(seconds: 2), bool reconnect = true, Duration reconnectDelay = const Duration(seconds: 1), Duration? timeout}) Stream<String>

Available on PodmanClient, provided by the PodmanClientContainerApi extension

Polls container logs with since cursors.
watchPodStats({PodStatsOptions options = const PodStatsOptions(), Duration pollInterval = const Duration(seconds: 2), bool reconnect = true, Duration reconnectDelay = const Duration(seconds: 1), Duration? timeout}) Stream<List<PodStatsReport>>

Available on PodmanClient, provided by the PodmanClientPodApi extension

Polls pod stats continuously.
watchPodTop(String pod, {PodTopOptions options = const PodTopOptions(), Duration pollInterval = const Duration(seconds: 2), bool reconnect = true, Duration reconnectDelay = const Duration(seconds: 1), Duration? timeout}) Stream<PodTopReport>

Available on PodmanClient, provided by the PodmanClientPodApi extension

Polls pod top output continuously.
watchStats(String container, {Duration pollInterval = const Duration(seconds: 2), bool reconnect = true, Duration reconnectDelay = const Duration(seconds: 1), Duration? timeout}) Stream<ContainerStats>

Available on PodmanClient, provided by the PodmanClientContainerRuntimeApi extension

Polls container stats continuously.

Operators

operator ==(Object other) bool
The equality operator.
inherited