SystemDfVolume class final

Volume row from GET /libpod/system/df.

Constructors

SystemDfVolume({required String volumeName, required int links, required int size, required int reclaimableSize, required Map<String, Object?> raw})
Creates a system-df volume row.
const
SystemDfVolume.fromJson(Map<String, Object?> json)
Builds SystemDfVolume from JSON.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
Number of links/users.
final
raw Map<String, Object?>
Raw payload.
final
reclaimableSize int
Reclaimable size in bytes.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int
Total size in bytes.
final
volumeName String
Volume name.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited