VolumeCreateOptions class final

Options for creating a Podman volume.

Constructors

VolumeCreateOptions({String? name, String driver = 'local', Map<String, String> labels = const <String, String>{}, Map<String, String> options = const <String, String>{}})
Creates volume options.
const

Properties

driver String
Volume driver.
final
hashCode int
The hash code for this object.
no setterinherited
labels Map<String, String>
Labels attached to the volume.
final
name String?
Optional volume name. Podman will auto-generate one when omitted.
final
options Map<String, String>
Driver options.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toApiBody() Map<String, Object?>
Serializes options for the libpod volume create API.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited