VolumePruneReport class final

Volume prune report item from POST /libpod/volumes/prune.

Constructors

VolumePruneReport({required String id, required String? error, required int size, required Map<String, Object?> raw})
Creates volume prune report.
const
VolumePruneReport.fromJson(Map<String, Object?> json)
Builds VolumePruneReport from JSON.
factory

Properties

error String?
Prune error if present.
final
hashCode int
The hash code for this object.
no setterinherited
id String
Pruned volume ID/name.
final
raw Map<String, Object?>
Raw payload.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int
Reclaimed bytes.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited