VolumeSummary class final

Volume summary from GET /libpod/volumes/json.

Constructors

VolumeSummary({required String name, required String driver, required String mountpoint, required DateTime? createdAt, required String scope, required int mountCount, required Map<String, String> labels, required Map<String, String> options, required Map<String, Object?> raw})
Creates a volume summary.
const
VolumeSummary.fromJson(Map<String, Object?> json)
Builds VolumeSummary from JSON.
factory

Properties

createdAt DateTime?
Creation timestamp.
final
driver String
Driver name.
final
hashCode int
The hash code for this object.
no setterinherited
labels Map<String, String>
Volume labels.
final
mountCount int
Active mount count.
final
mountpoint String
Volume mountpoint.
final
name String
Volume name.
final
options Map<String, String>
Driver options.
final
raw Map<String, Object?>
Raw payload.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scope String
Scope (local, etc).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited