ImageRemoveResult class final
Image removal result from libpod image remove endpoints.
Constructors
-
ImageRemoveResult({required List<
String> deleted, required List<String> untagged, required int exitCode, required List<String> errors, required Map<String, Object?> raw}) -
Creates image remove result.
const
-
ImageRemoveResult.fromJson(Map<
String, Object?> json) -
Builds ImageRemoveResult from JSON.
factory
Properties
-
deleted
→ List<
String> -
Deleted image IDs.
final
-
errors
→ List<
String> -
Removal errors.
final
- exitCode → int
-
Command-style exit code from Podman.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
raw
→ Map<
String, Object?> -
Raw payload.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
untagged
→ List<
String> -
Untagged image references.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited