NetworkCreateOptions class final
Options for creating a Podman network.
Constructors
-
NetworkCreateOptions({required String name, String driver = 'bridge', bool? internal, bool? ipv6Enabled, bool? dnsEnabled, Map<
String, String> labels = const <String, String>{}, Map<String, String> options = const <String, String>{}, String? subnet, String? gateway}) -
Creates network creation options.
const
Properties
- dnsEnabled → bool?
-
Whether DNS should be enabled.
final
- driver → String
-
Network driver.
final
- gateway → String?
-
Optional gateway IP.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- internal → bool?
-
Whether network should be internal-only.
final
- ipv6Enabled → bool?
-
Whether IPv6 should be enabled.
final
-
labels
→ Map<
String, String> -
User-defined labels.
final
- name → String
-
Network name.
final
-
options
→ Map<
String, String> -
Driver-specific options.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subnet → String?
-
Optional CIDR subnet.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toApiBody(
) → Map< String, Object?> - Serializes options for the libpod create-network API.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited