NetworkDetails class final
Detailed network data from GET /libpod/networks/{name}/json.
Constructors
-
NetworkDetails({required String id, required String name, required String driver, required String networkInterface, required bool internal, required bool ipv6Enabled, required bool dnsEnabled, required DateTime? createdAt, required Map<
String, String> labels, required Map<String, String> options, required List<NetworkSubnet> subnets, required Map<String, Object?> raw}) -
Creates network details.
const
-
NetworkDetails.fromJson(Map<
String, Object?> json) -
Builds NetworkDetails from JSON.
factory
Properties
- createdAt → DateTime?
-
Creation timestamp.
final
- dnsEnabled → bool
-
DNS-enabled flag.
final
- driver → String
-
Driver name.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Network ID.
final
- internal → bool
-
Internal-only flag.
final
- ipv6Enabled → bool
-
IPv6-enabled flag.
final
-
labels
→ Map<
String, String> -
Labels.
final
- name → String
-
Network name.
final
- networkInterface → String
-
Host interface name.
final
-
options
→ Map<
String, String> -
Driver options.
final
-
raw
→ Map<
String, Object?> -
Raw payload.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
subnets
→ List<
NetworkSubnet> -
Subnet definitions.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited