PodStatsReport class final
Pod stats item from GET /libpod/pods/stats.
Constructors
-
PodStatsReport({required String podId, required String containerId, required String name, required String cpuPercent, required String memoryUsage, required String memoryUsageBytes, required String memoryPercent, required String networkIo, required String blockIo, required String pids, required Map<
String, Object?> raw}) -
Creates a pod stats report.
const
-
PodStatsReport.fromJson(Map<
String, Object?> json) -
Builds PodStatsReport from JSON.
factory
Properties
- blockIo → String
-
Block I/O value.
final
- containerId → String
-
Container ID.
final
- cpuPercent → String
-
CPU usage percent.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- memoryPercent → String
-
Memory percent.
final
- memoryUsage → String
-
Humanized memory usage.
final
- memoryUsageBytes → String
-
Memory usage/limit in bytes.
final
- name → String
-
Pod name.
final
- networkIo → String
-
Network I/O value.
final
- pids → String
-
PID count.
final
- podId → String
-
Pod ID.
final
-
raw
→ Map<
String, Object?> -
Raw payload.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited