PodmanApiException class final
Exception thrown when Podman API returns an unexpected response.
- Inheritance
-
- Object
- PodmanException
- PodmanApiException
Constructors
- PodmanApiException({required HttpMethod method, required String path, required int statusCode, required String responseBody, String? message})
- Creates an API exception.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotFound → bool
-
Whether the response represents a not-found condition.
no setter
- message → String
-
Error message.
finalinherited
- method → HttpMethod
-
Request method.
final
- path → String
-
Request path.
final
- responseBody → String
-
Raw response body.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- statusCode → int
-
HTTP status code.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited