PortBinding class final
Podman container port mapping.
Constructors
- PortBinding.expose(int containerPort, {String protocol = 'tcp'})
-
Exposes
containerPortwithout binding to a specific host port.const - PortBinding.publish(int? hostPort, int containerPort, {String protocol = 'tcp', String? hostIp})
-
Publishes
containerPortonhostPort.const
Properties
- apiKey → String
-
Podman/Docker API exposed port key format (
80/tcp).no setter - containerPort → int
-
Container port.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasHostBinding → bool
-
Whether host-side binding is defined.
no setter
- hostIp → String?
-
Optional host IP.
final
- hostPort → int?
-
Host port.
final
- protocol → String
-
Protocol (usually
tcporudp).final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toApiBindingJson(
) → Map< String, String> - Serializes to API port binding entry.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited