SystemPruneReport class final
System prune report from POST /libpod/system/prune.
Constructors
-
SystemPruneReport({required List<
String> podIds, required List<String> containerIds, required List<String> imageIds, required List<String> networkNames, required List<String> volumeIds, required int reclaimedSpace, required Map<String, Object?> raw}) -
Creates a system-prune report.
const
-
SystemPruneReport.fromJson(Map<
String, Object?> json) -
Builds SystemPruneReport from JSON.
factory
Properties
-
containerIds
→ List<
String> -
Pruned container IDs.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
imageIds
→ List<
String> -
Pruned image IDs.
final
-
networkNames
→ List<
String> -
Pruned network names.
final
-
podIds
→ List<
String> -
Pruned pod IDs.
final
-
raw
→ Map<
String, Object?> -
Raw payload.
final
- reclaimedSpace → int
-
Total reclaimed bytes.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
volumeIds
→ List<
String> -
Pruned volume IDs.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited